==> pyesdoc-0.9.7.3.1.tar.gz: pyesdoc-0.9.7.3.1/pyesdoc/mp/specializations/cmip6/land_nitrogen_cycle.py <==
"""A realm process sepecialization.

For further information goto http://wordpress.es-doc.org/cmip6-model-specializations.

"""
# --------------------------------------------------------------------
# INTERNAL (do not change)
# --------------------------------------------------------------------
from collections import OrderedDict

DETAILS = OrderedDict()
ENUMERATIONS = OrderedDict()

# --------------------------------------------------------------------
# CONTACT: Set to realm specialization co-ordinator.
# --------------------------------------------------------------------
CONTACT = 'David Hassell'

# --------------------------------------------------------------------
# AUTHORS: Set to realm specialization authors (comma delimited).
# --------------------------------------------------------------------
AUTHORS = 'David Hassell'

# --------------------------------------------------------------------
# QUALITY CONTROL STATUS: Set to 'draft' or 'complete'
# --------------------------------------------------------------------
QC_STATUS = 'draft'

# --------------------------------------------------------------------
# DESCRIPTION: Short description of the specialization.
# --------------------------------------------------------------------
DESCRIPTION = 'Land surface nitrogen cycle'

# --------------------------------------------------------------------
# NITROGEN CYCLE: top level
# --------------------------------------------------------------------
DETAILS['toplevel'] = {
    'description': 'Place-holder for nitrogren cycle',
    'properties' : [
    ],
}

# --------------------------------------------------------------------
# NITROGEN CYCLE: process
# --------------------------------------------------------------------

# --------------------------------------------------------------------
# NITROGEN CYCLE: process
# --------------------------------------------------------------------

# --------------------------------------------------------------------
# NITROGEN CYCLE: process
# --------------------------------------------------------------------

# --------------------------------------------------------------------
# NITROGEN CYCLE: process
# --------------------------------------------------------------------

# --------------------------------------------------------------------
# NITROGEN CYCLE: ENUMERATIONS
# --------------------------------------------------------------------

==> pyesdoc-0.9.7.3.4.tar.gz: pyesdoc-0.9.7.3.4/pyesdoc/mp/specializations/cmip6/land_nitrogen_cycle.py <==
"""A realm process sepecialization.

For further information goto http://wordpress.es-doc.org/cmip6-model-specializations.

"""
# --------------------------------------------------------------------
# INTERNAL (do not change)
# --------------------------------------------------------------------
from collections import OrderedDict

DETAILS = OrderedDict()
ENUMERATIONS = OrderedDict()

# --------------------------------------------------------------------
# CONTACT: Set to realm specialization co-ordinator.
# --------------------------------------------------------------------
CONTACT = 'David Hassell'

# --------------------------------------------------------------------
# AUTHORS: Set to realm specialization authors (comma delimited).
# --------------------------------------------------------------------
AUTHORS = 'David Hassell'

# --------------------------------------------------------------------
# QUALITY CONTROL STATUS: Set to 'draft' or 'complete'
# --------------------------------------------------------------------
QC_STATUS = 'draft'

# --------------------------------------------------------------------
# DESCRIPTION: Short description of the specialization.
# --------------------------------------------------------------------
DESCRIPTION = 'Land surface nitrogen cycle'

# --------------------------------------------------------------------
# NITROGEN CYCLE: top level
# --------------------------------------------------------------------
DETAILS['toplevel'] = {
    'description': 'Properties of land surface nitrogen cycle',
    'properties': [
        ('tiling', 'str', '0.1',
             'Describe the notrogen cycle tiling, if any.'),
    ]
}

# --------------------------------------------------------------------
# NITROGEN CYCLE: process
# --------------------------------------------------------------------

# --------------------------------------------------------------------
# NITROGEN CYCLE: process
# --------------------------------------------------------------------

# --------------------------------------------------------------------
# NITROGEN CYCLE: process
# --------------------------------------------------------------------

# --------------------------------------------------------------------
# NITROGEN CYCLE: process
# --------------------------------------------------------------------

# --------------------------------------------------------------------
# NITROGEN CYCLE: ENUMERATIONS
# --------------------------------------------------------------------
